@@ -24,6 +24,7 @@ int ast_term_init(void);		/*!< Provided by term.c */
 int astdb_init(void);			/*!< Provided by db.c */
 void ast_channels_init(void);		/*!< Provided by channel.c */
 void ast_builtins_init(void);		/*!< Provided by cli.c */
+int ast_cli_perms_init(int reload);	/*!< Provided by cli.c */
 int dnsmgr_init(void);			/*!< Provided by dnsmgr.c */ 
 void dnsmgr_start_refresh(void);	/*!< Provided by dnsmgr.c */
 int dnsmgr_reload(void);		/*!< Provided by dnsmgr.c */
@@ -38,6 +39,8 @@ int ast_http_init(void);		/*!< Provided by http.c */
 int ast_http_reload(void);		/*!< Provided by http.c */
 int ast_tps_init(void); 		/*!< Provided by taskprocessor.c */
 int ast_timing_init(void);		/*!< Provided by timing.c */
+int ast_indications_init(void); /*!< Provided by indications.c */
+int ast_indications_reload(void);/*!< Provided by indications.c */
 int ast_ssl_init(void);                 /*!< Porvided by ssl.c */
 
 /*!
@@ -69,4 +72,10 @@ int ast_module_reload(const char *name);
  */
 void ast_process_pending_reloads(void);
 
+/*! \brief Load XML documentation. Provided by xmldoc.c 
+ *  \retval 1 on error.
+ *  \retval 0 on success. 
+ */
+int ast_xmldoc_load_documentation(void);
+
 #endif /* _ASTERISK__PRIVATE_H */
