@@ -27,7 +27,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 201096 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 223490 $")
 
 #include <sys/time.h>
 #include <signal.h>
@@ -72,6 +72,11 @@ static int as_chan_list_state;
 
 static void *autoservice_run(void *ign)
 {
+	struct ast_frame hangup_frame = {
+		.frametype = AST_FRAME_CONTROL,
+		.subclass = AST_CONTROL_HANGUP,
+	};
+
 	for (;;) {
 		struct ast_channel *mons[MAX_AUTOMONS];
 		struct asent *ents[MAX_AUTOMONS];
@@ -114,18 +119,14 @@ static void *autoservice_run(void *ign)
 		}
 
 		f = ast_read(chan);
-	
+
 		if (!f) {
-			struct ast_frame hangup_frame = { 0, };
 			/* No frame means the channel has been hung up.
 			 * A hangup frame needs to be queued here as ast_waitfor() may
 			 * never return again for the condition to be detected outside
 			 * of autoservice.  So, we'll leave a HANGUP queued up so the
 			 * thread in charge of this channel will know. */
 
-			hangup_frame.frametype = AST_FRAME_CONTROL;
-			hangup_frame.subclass = AST_CONTROL_HANGUP;
-
 			defer_frame = &hangup_frame;
 		} else {
 
