@@ -29,15 +29,9 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 117507 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 126356 $")
 
-#include <sys/types.h>
-#include <stdlib.h>
 #include <fcntl.h>
-#include <unistd.h>
-#include <stdio.h>
-#include <string.h>
-#include <stdarg.h>
 #include <signal.h>
 #include <sys/time.h>
 
@@ -48,7 +42,6 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 117507 $")
 #include "asterisk/config.h"
 #include "asterisk/module.h"
 #include "asterisk/logger.h"
-#include "asterisk/options.h"
 #include "asterisk/cli.h"
 #include "asterisk/utils.h"
 #include "asterisk/paths.h"
@@ -244,7 +237,7 @@ static int reload(void)
 		}
 	}
 
-	return 0;
+	return AST_MODULE_LOAD_SUCCESS;
 }
 
 static void file_ok_sel(GtkWidget *w, GtkFileSelection *fs)
@@ -314,14 +307,15 @@ static int mod_update(void)
 
 static void exit_now(GtkWidget *widget, gpointer data)
 {
+	int res;
+
 	ast_loader_unregister(mod_update);
 	gtk_main_quit();
 	inuse--;
 	ast_update_use_count();
-	ast_unregister_verbose(verboser);
+	res = ast_unregister_verbose(verboser);
 	ast_unload_resource("pbx_gtkconsole", 0);
-	if (option_verbose > 1)
-		ast_verbose(VERBOSE_PREFIX_2 "GTK Console Monitor Exiting\n");
+	ast_verb(2, "GTK Console Monitor Exiting\n");
 	/* XXX Trying to quit after calling this makes asterisk segfault XXX */
 }
 
@@ -369,6 +363,8 @@ static int show_console(void)
 	GtkWidget *sw;
 	GtkWidget *bbox, *hbbox, *add, *removew, *reloadw;
 	char *modtitles[3] = { "Module", "Description", "Use Count" };
+	int res;
+
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	
 	statusbar = gtk_statusbar_new();
@@ -473,7 +469,7 @@ static int show_console(void)
 	ast_pthread_create(&console_thread, NULL, consolethread, NULL);
 	/* XXX Okay, seriously fix me! XXX */
 	usleep(100000);
-	ast_register_verbose(verboser);
+	res = ast_register_verbose(verboser);
 	gtk_clist_freeze(GTK_CLIST(verb));
 	ast_loader_register(mod_update);
 	gtk_clist_thaw(GTK_CLIST(verb));
@@ -488,24 +484,23 @@ static int load_module(void)
 {
 	if (pipe(clipipe)) {
 		ast_log(LOG_WARNING, "Unable to create CLI pipe\n");
-		return -1;
+		return AST_MODULE_LOAD_FAILURE;
 	}
 	g_thread_init(NULL);
 	if (gtk_init_check(NULL, NULL))  {
 		if (!show_console()) {
 			inuse++;
 			ast_update_use_count();
-			if (option_verbose > 1)
-				ast_verbose( VERBOSE_PREFIX_2 "Launched GTK Console monitor\n");		
+			ast_verb(2, "Launched GTK Console monitor\n");
 		} else
 			ast_log(LOG_WARNING, "Unable to start GTK console\n");
 	} else {
 		if (option_debug)
 			ast_log(LOG_DEBUG, "Unable to start GTK console monitor -- ignoring\n");
-		else if (option_verbose > 1)
-			ast_verbose( VERBOSE_PREFIX_2 "GTK is not available -- skipping monitor\n");
+		else
+			ast_verb(2, "GTK is not available -- skipping monitor\n");
 	}
-	return 0;
+	return AST_MODULE_LOAD_SUCCESS;
 }
 
 AST_MODULE_INFO(ASTERISK_GPL_KEY, AST_MODFLAG_DEFAULT, "GTK Console",
