@@ -32,7 +32,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 234213 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 250790 $")
 
 #include <ctype.h>
 #include <signal.h>
@@ -46,6 +46,10 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 234213 $")
 #include <thread.h>
 #endif
 
+#ifdef SOLARIS
+#include <thread.h>
+#endif
+
 #ifdef HAVE_DAHDI
 #include <dahdi/user.h>
 #endif
@@ -530,7 +534,7 @@ static int spawn_mp3(struct mohclass *class)
 		ast_close_fds_above_n(STDERR_FILENO);
 
 		/* Child */
-		if (strcasecmp(class->dir, "nodir") && chdir(class->dir) < 0) {
+		if (strncasecmp(class->dir, "http://", 7) && strcasecmp(class->dir, "nodir") && chdir(class->dir) < 0) {
 			ast_log(LOG_WARNING, "chdir() failed: %s\n", strerror(errno));
 			_exit(1);
 		}
